@@ -94,6 +94,9 @@ def process_grid(procstatus, dscfg, radar_list=None):
                 minimum and maximum horizontal distance from grid origin [km]
                 and minimum and maximum vertical distance from grid origin [m]
                 Defaults -40, 40, -40, 40, 0., 10000.
+            latmin, latmax, lonmin, lonmax : floats
+                minimum and maximum latitude and longitude [deg], if specified
+                xmin, xmax, ymin, ymax will be ignored
             hres, vres : floats
                 horizontal and vertical grid resolution [m]
                 Defaults 1000., 500.
@@ -169,11 +172,24 @@ def process_grid(procstatus, dscfg, radar_list=None):
     zmax = 10000.
     hres = 1000.
     vres = 500.
+    lonmin = None
+    lonmax = None
+    latmin = None
+    latmax = None
+
     lat = float(radar.latitude['data'])
     lon = float(radar.longitude['data'])
     alt = float(radar.altitude['data'])
 
     if 'gridConfig' in dscfg:
+        if 'latmin' in dscfg['gridConfig']:
+            latmin = dscfg['gridConfig']['latmin']
+        if 'latmax' in dscfg['gridConfig']:
+            latmax = dscfg['gridConfig']['latmax']
+        if 'lonmin' in dscfg['gridConfig']:
+            lonmin = dscfg['gridConfig']['lonmin']
+        if 'lonmax' in dscfg['gridConfig']:
+            lonmax = dscfg['gridConfig']['lonmax']
         if 'xmin' in dscfg['gridConfig']:
             xmin = dscfg['gridConfig']['xmin']
         if 'xmax' in dscfg['gridConfig']:
@@ -197,6 +213,19 @@ def process_grid(procstatus, dscfg, radar_list=None):
         if 'altorig' in dscfg['gridConfig']:
             alt = dscfg['gridConfig']['altorig']
 
+    if (latmin is not None and latmax is not None and 
+        lonmin is not None and lonmax is not None):
+        # get xmin, xmax, ymin, ymax from lon/lat
+        gatelat = radar.gate_latitude['data']
+        gatelon = radar.gate_longitude['data']
+        mask1 = np.logical_and(gatelat > latmin, gatelat <= latmax)
+        mask2 = np.logical_and(gatelon > lonmin, gatelon <= lonmax)
+        mask = np.logical_and(mask1, mask2)
+        xmin = np.min(radar.gate_x['data'][mask]) / 1000.
+        xmax = np.max(radar.gate_x['data'][mask]) / 1000.
+        ymin = np.min(radar.gate_y['data'][mask]) / 1000.
+        ymax = np.max(radar.gate_y['data'][mask]) / 1000.
+
     wfunc = dscfg.get('wfunc', 'NEAREST')
     roi_func = dscfg.get('roi_func', 'dist_beam')
 
